@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_BARCELONA,
+  sbgemm_small_kernel_nn_BARCELONA, sbgemm_small_kernel_nt_BARCELONA, sbgemm_small_kernel_tn_BARCELONA, sbgemm_small_kernel_tt_BARCELONA,
+  sbgemm_small_kernel_b0_nn_BARCELONA, sbgemm_small_kernel_b0_nt_BARCELONA, sbgemm_small_kernel_b0_tn_BARCELONA, sbgemm_small_kernel_b0_tt_BARCELONA,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_BARCELONA, sgemm_otcopy_BARCELONA,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_BARCELONA,
+  sgemm_small_kernel_nn_BARCELONA, sgemm_small_kernel_nt_BARCELONA, sgemm_small_kernel_tn_BARCELONA, sgemm_small_kernel_tt_BARCELONA,
+  sgemm_small_kernel_b0_nn_BARCELONA, sgemm_small_kernel_b0_nt_BARCELONA, sgemm_small_kernel_b0_tn_BARCELONA, sgemm_small_kernel_b0_tt_BARCELONA,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_BARCELONA, strsm_kernel_LT_BARCELONA, strsm_kernel_RN_BARCELONA, strsm_kernel_RT_BARCELONA,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_BARCELONA,
+  dgemm_small_kernel_nn_BARCELONA, dgemm_small_kernel_nt_BARCELONA, dgemm_small_kernel_tn_BARCELONA, dgemm_small_kernel_tt_BARCELONA,
+  dgemm_small_kernel_b0_nn_BARCELONA, dgemm_small_kernel_b0_nt_BARCELONA, dgemm_small_kernel_b0_tn_BARCELONA, dgemm_small_kernel_b0_tt_BARCELONA,
+#endif
   dtrsm_kernel_LN_BARCELONA, dtrsm_kernel_LT_BARCELONA, dtrsm_kernel_RN_BARCELONA, dtrsm_kernel_RT_BARCELONA,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_BARCELONA, dtrsm_iunncopy_BARCELONA, dtrsm_iutucopy_BARCELONA, dtrsm_iutncopy_BARCELONA,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_BARCELONA, cgemm_otcopy_BARCELONA,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_BARCELONA,
+  cgemm_small_kernel_nn_BARCELONA, cgemm_small_kernel_nt_BARCELONA, cgemm_small_kernel_nr_BARCELONA, cgemm_small_kernel_nc_BARCELONA,
+  cgemm_small_kernel_tn_BARCELONA, cgemm_small_kernel_tt_BARCELONA, cgemm_small_kernel_tr_BARCELONA, cgemm_small_kernel_tc_BARCELONA,
+  cgemm_small_kernel_rn_BARCELONA, cgemm_small_kernel_rt_BARCELONA, cgemm_small_kernel_rr_BARCELONA, cgemm_small_kernel_rc_BARCELONA,
+  cgemm_small_kernel_cn_BARCELONA, cgemm_small_kernel_ct_BARCELONA, cgemm_small_kernel_cr_BARCELONA, cgemm_small_kernel_cc_BARCELONA,
+  cgemm_small_kernel_b0_nn_BARCELONA, cgemm_small_kernel_b0_nt_BARCELONA, cgemm_small_kernel_b0_nr_BARCELONA, cgemm_small_kernel_b0_nc_BARCELONA,
+  cgemm_small_kernel_b0_tn_BARCELONA, cgemm_small_kernel_b0_tt_BARCELONA, cgemm_small_kernel_b0_tr_BARCELONA, cgemm_small_kernel_b0_tc_BARCELONA,
+  cgemm_small_kernel_b0_rn_BARCELONA, cgemm_small_kernel_b0_rt_BARCELONA, cgemm_small_kernel_b0_rr_BARCELONA, cgemm_small_kernel_b0_rc_BARCELONA,
+  cgemm_small_kernel_b0_cn_BARCELONA, cgemm_small_kernel_b0_ct_BARCELONA, cgemm_small_kernel_b0_cr_BARCELONA, cgemm_small_kernel_b0_cc_BARCELONA,
+#endif
+
   ctrsm_kernel_LN_BARCELONA, ctrsm_kernel_LT_BARCELONA, ctrsm_kernel_LR_BARCELONA, ctrsm_kernel_LC_BARCELONA,
   ctrsm_kernel_RN_BARCELONA, ctrsm_kernel_RT_BARCELONA, ctrsm_kernel_RR_BARCELONA, ctrsm_kernel_RC_BARCELONA,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_BARCELONA, zgemm_otcopy_BARCELONA,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_BARCELONA,
+  zgemm_small_kernel_nn_BARCELONA, zgemm_small_kernel_nt_BARCELONA, zgemm_small_kernel_nr_BARCELONA, zgemm_small_kernel_nc_BARCELONA,
+  zgemm_small_kernel_tn_BARCELONA, zgemm_small_kernel_tt_BARCELONA, zgemm_small_kernel_tr_BARCELONA, zgemm_small_kernel_tc_BARCELONA,
+  zgemm_small_kernel_rn_BARCELONA, zgemm_small_kernel_rt_BARCELONA, zgemm_small_kernel_rr_BARCELONA, zgemm_small_kernel_rc_BARCELONA,
+  zgemm_small_kernel_cn_BARCELONA, zgemm_small_kernel_ct_BARCELONA, zgemm_small_kernel_cr_BARCELONA, zgemm_small_kernel_cc_BARCELONA,
+  zgemm_small_kernel_b0_nn_BARCELONA, zgemm_small_kernel_b0_nt_BARCELONA, zgemm_small_kernel_b0_nr_BARCELONA, zgemm_small_kernel_b0_nc_BARCELONA,
+  zgemm_small_kernel_b0_tn_BARCELONA, zgemm_small_kernel_b0_tt_BARCELONA, zgemm_small_kernel_b0_tr_BARCELONA, zgemm_small_kernel_b0_tc_BARCELONA,
+  zgemm_small_kernel_b0_rn_BARCELONA, zgemm_small_kernel_b0_rt_BARCELONA, zgemm_small_kernel_b0_rr_BARCELONA, zgemm_small_kernel_b0_rc_BARCELONA,
+  zgemm_small_kernel_b0_cn_BARCELONA, zgemm_small_kernel_b0_ct_BARCELONA, zgemm_small_kernel_b0_cr_BARCELONA, zgemm_small_kernel_b0_cc_BARCELONA,
+#endif
+
   ztrsm_kernel_LN_BARCELONA, ztrsm_kernel_LT_BARCELONA, ztrsm_kernel_LR_BARCELONA, ztrsm_kernel_LC_BARCELONA,
   ztrsm_kernel_RN_BARCELONA, ztrsm_kernel_RT_BARCELONA, ztrsm_kernel_RR_BARCELONA, ztrsm_kernel_RC_BARCELONA,
 
