@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_BULLDOZER,
+  sbgemm_small_kernel_nn_BULLDOZER, sbgemm_small_kernel_nt_BULLDOZER, sbgemm_small_kernel_tn_BULLDOZER, sbgemm_small_kernel_tt_BULLDOZER,
+  sbgemm_small_kernel_b0_nn_BULLDOZER, sbgemm_small_kernel_b0_nt_BULLDOZER, sbgemm_small_kernel_b0_tn_BULLDOZER, sbgemm_small_kernel_b0_tt_BULLDOZER,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_BULLDOZER, sgemm_otcopy_BULLDOZER,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_BULLDOZER,
+  sgemm_small_kernel_nn_BULLDOZER, sgemm_small_kernel_nt_BULLDOZER, sgemm_small_kernel_tn_BULLDOZER, sgemm_small_kernel_tt_BULLDOZER,
+  sgemm_small_kernel_b0_nn_BULLDOZER, sgemm_small_kernel_b0_nt_BULLDOZER, sgemm_small_kernel_b0_tn_BULLDOZER, sgemm_small_kernel_b0_tt_BULLDOZER,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_BULLDOZER, strsm_kernel_LT_BULLDOZER, strsm_kernel_RN_BULLDOZER, strsm_kernel_RT_BULLDOZER,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_BULLDOZER,
+  dgemm_small_kernel_nn_BULLDOZER, dgemm_small_kernel_nt_BULLDOZER, dgemm_small_kernel_tn_BULLDOZER, dgemm_small_kernel_tt_BULLDOZER,
+  dgemm_small_kernel_b0_nn_BULLDOZER, dgemm_small_kernel_b0_nt_BULLDOZER, dgemm_small_kernel_b0_tn_BULLDOZER, dgemm_small_kernel_b0_tt_BULLDOZER,
+#endif
   dtrsm_kernel_LN_BULLDOZER, dtrsm_kernel_LT_BULLDOZER, dtrsm_kernel_RN_BULLDOZER, dtrsm_kernel_RT_BULLDOZER,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_BULLDOZER, dtrsm_iunncopy_BULLDOZER, dtrsm_iutucopy_BULLDOZER, dtrsm_iutncopy_BULLDOZER,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_BULLDOZER, cgemm_otcopy_BULLDOZER,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_BULLDOZER,
+  cgemm_small_kernel_nn_BULLDOZER, cgemm_small_kernel_nt_BULLDOZER, cgemm_small_kernel_nr_BULLDOZER, cgemm_small_kernel_nc_BULLDOZER,
+  cgemm_small_kernel_tn_BULLDOZER, cgemm_small_kernel_tt_BULLDOZER, cgemm_small_kernel_tr_BULLDOZER, cgemm_small_kernel_tc_BULLDOZER,
+  cgemm_small_kernel_rn_BULLDOZER, cgemm_small_kernel_rt_BULLDOZER, cgemm_small_kernel_rr_BULLDOZER, cgemm_small_kernel_rc_BULLDOZER,
+  cgemm_small_kernel_cn_BULLDOZER, cgemm_small_kernel_ct_BULLDOZER, cgemm_small_kernel_cr_BULLDOZER, cgemm_small_kernel_cc_BULLDOZER,
+  cgemm_small_kernel_b0_nn_BULLDOZER, cgemm_small_kernel_b0_nt_BULLDOZER, cgemm_small_kernel_b0_nr_BULLDOZER, cgemm_small_kernel_b0_nc_BULLDOZER,
+  cgemm_small_kernel_b0_tn_BULLDOZER, cgemm_small_kernel_b0_tt_BULLDOZER, cgemm_small_kernel_b0_tr_BULLDOZER, cgemm_small_kernel_b0_tc_BULLDOZER,
+  cgemm_small_kernel_b0_rn_BULLDOZER, cgemm_small_kernel_b0_rt_BULLDOZER, cgemm_small_kernel_b0_rr_BULLDOZER, cgemm_small_kernel_b0_rc_BULLDOZER,
+  cgemm_small_kernel_b0_cn_BULLDOZER, cgemm_small_kernel_b0_ct_BULLDOZER, cgemm_small_kernel_b0_cr_BULLDOZER, cgemm_small_kernel_b0_cc_BULLDOZER,
+#endif
+
   ctrsm_kernel_LN_BULLDOZER, ctrsm_kernel_LT_BULLDOZER, ctrsm_kernel_LR_BULLDOZER, ctrsm_kernel_LC_BULLDOZER,
   ctrsm_kernel_RN_BULLDOZER, ctrsm_kernel_RT_BULLDOZER, ctrsm_kernel_RR_BULLDOZER, ctrsm_kernel_RC_BULLDOZER,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_BULLDOZER, zgemm_otcopy_BULLDOZER,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_BULLDOZER,
+  zgemm_small_kernel_nn_BULLDOZER, zgemm_small_kernel_nt_BULLDOZER, zgemm_small_kernel_nr_BULLDOZER, zgemm_small_kernel_nc_BULLDOZER,
+  zgemm_small_kernel_tn_BULLDOZER, zgemm_small_kernel_tt_BULLDOZER, zgemm_small_kernel_tr_BULLDOZER, zgemm_small_kernel_tc_BULLDOZER,
+  zgemm_small_kernel_rn_BULLDOZER, zgemm_small_kernel_rt_BULLDOZER, zgemm_small_kernel_rr_BULLDOZER, zgemm_small_kernel_rc_BULLDOZER,
+  zgemm_small_kernel_cn_BULLDOZER, zgemm_small_kernel_ct_BULLDOZER, zgemm_small_kernel_cr_BULLDOZER, zgemm_small_kernel_cc_BULLDOZER,
+  zgemm_small_kernel_b0_nn_BULLDOZER, zgemm_small_kernel_b0_nt_BULLDOZER, zgemm_small_kernel_b0_nr_BULLDOZER, zgemm_small_kernel_b0_nc_BULLDOZER,
+  zgemm_small_kernel_b0_tn_BULLDOZER, zgemm_small_kernel_b0_tt_BULLDOZER, zgemm_small_kernel_b0_tr_BULLDOZER, zgemm_small_kernel_b0_tc_BULLDOZER,
+  zgemm_small_kernel_b0_rn_BULLDOZER, zgemm_small_kernel_b0_rt_BULLDOZER, zgemm_small_kernel_b0_rr_BULLDOZER, zgemm_small_kernel_b0_rc_BULLDOZER,
+  zgemm_small_kernel_b0_cn_BULLDOZER, zgemm_small_kernel_b0_ct_BULLDOZER, zgemm_small_kernel_b0_cr_BULLDOZER, zgemm_small_kernel_b0_cc_BULLDOZER,
+#endif
+
   ztrsm_kernel_LN_BULLDOZER, ztrsm_kernel_LT_BULLDOZER, ztrsm_kernel_LR_BULLDOZER, ztrsm_kernel_LC_BULLDOZER,
   ztrsm_kernel_RN_BULLDOZER, ztrsm_kernel_RT_BULLDOZER, ztrsm_kernel_RR_BULLDOZER, ztrsm_kernel_RC_BULLDOZER,
 
