@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_COOPERLAKE,
+  sbgemm_small_kernel_nn_COOPERLAKE, sbgemm_small_kernel_nt_COOPERLAKE, sbgemm_small_kernel_tn_COOPERLAKE, sbgemm_small_kernel_tt_COOPERLAKE,
+  sbgemm_small_kernel_b0_nn_COOPERLAKE, sbgemm_small_kernel_b0_nt_COOPERLAKE, sbgemm_small_kernel_b0_tn_COOPERLAKE, sbgemm_small_kernel_b0_tt_COOPERLAKE,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_COOPERLAKE, sgemm_otcopy_COOPERLAKE,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_COOPERLAKE,
+  sgemm_small_kernel_nn_COOPERLAKE, sgemm_small_kernel_nt_COOPERLAKE, sgemm_small_kernel_tn_COOPERLAKE, sgemm_small_kernel_tt_COOPERLAKE,
+  sgemm_small_kernel_b0_nn_COOPERLAKE, sgemm_small_kernel_b0_nt_COOPERLAKE, sgemm_small_kernel_b0_tn_COOPERLAKE, sgemm_small_kernel_b0_tt_COOPERLAKE,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_COOPERLAKE, strsm_kernel_LT_COOPERLAKE, strsm_kernel_RN_COOPERLAKE, strsm_kernel_RT_COOPERLAKE,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_COOPERLAKE,
+  dgemm_small_kernel_nn_COOPERLAKE, dgemm_small_kernel_nt_COOPERLAKE, dgemm_small_kernel_tn_COOPERLAKE, dgemm_small_kernel_tt_COOPERLAKE,
+  dgemm_small_kernel_b0_nn_COOPERLAKE, dgemm_small_kernel_b0_nt_COOPERLAKE, dgemm_small_kernel_b0_tn_COOPERLAKE, dgemm_small_kernel_b0_tt_COOPERLAKE,
+#endif
   dtrsm_kernel_LN_COOPERLAKE, dtrsm_kernel_LT_COOPERLAKE, dtrsm_kernel_RN_COOPERLAKE, dtrsm_kernel_RT_COOPERLAKE,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_COOPERLAKE, dtrsm_iunncopy_COOPERLAKE, dtrsm_iutucopy_COOPERLAKE, dtrsm_iutncopy_COOPERLAKE,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_COOPERLAKE, cgemm_otcopy_COOPERLAKE,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_COOPERLAKE,
+  cgemm_small_kernel_nn_COOPERLAKE, cgemm_small_kernel_nt_COOPERLAKE, cgemm_small_kernel_nr_COOPERLAKE, cgemm_small_kernel_nc_COOPERLAKE,
+  cgemm_small_kernel_tn_COOPERLAKE, cgemm_small_kernel_tt_COOPERLAKE, cgemm_small_kernel_tr_COOPERLAKE, cgemm_small_kernel_tc_COOPERLAKE,
+  cgemm_small_kernel_rn_COOPERLAKE, cgemm_small_kernel_rt_COOPERLAKE, cgemm_small_kernel_rr_COOPERLAKE, cgemm_small_kernel_rc_COOPERLAKE,
+  cgemm_small_kernel_cn_COOPERLAKE, cgemm_small_kernel_ct_COOPERLAKE, cgemm_small_kernel_cr_COOPERLAKE, cgemm_small_kernel_cc_COOPERLAKE,
+  cgemm_small_kernel_b0_nn_COOPERLAKE, cgemm_small_kernel_b0_nt_COOPERLAKE, cgemm_small_kernel_b0_nr_COOPERLAKE, cgemm_small_kernel_b0_nc_COOPERLAKE,
+  cgemm_small_kernel_b0_tn_COOPERLAKE, cgemm_small_kernel_b0_tt_COOPERLAKE, cgemm_small_kernel_b0_tr_COOPERLAKE, cgemm_small_kernel_b0_tc_COOPERLAKE,
+  cgemm_small_kernel_b0_rn_COOPERLAKE, cgemm_small_kernel_b0_rt_COOPERLAKE, cgemm_small_kernel_b0_rr_COOPERLAKE, cgemm_small_kernel_b0_rc_COOPERLAKE,
+  cgemm_small_kernel_b0_cn_COOPERLAKE, cgemm_small_kernel_b0_ct_COOPERLAKE, cgemm_small_kernel_b0_cr_COOPERLAKE, cgemm_small_kernel_b0_cc_COOPERLAKE,
+#endif
+
   ctrsm_kernel_LN_COOPERLAKE, ctrsm_kernel_LT_COOPERLAKE, ctrsm_kernel_LR_COOPERLAKE, ctrsm_kernel_LC_COOPERLAKE,
   ctrsm_kernel_RN_COOPERLAKE, ctrsm_kernel_RT_COOPERLAKE, ctrsm_kernel_RR_COOPERLAKE, ctrsm_kernel_RC_COOPERLAKE,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_COOPERLAKE, zgemm_otcopy_COOPERLAKE,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_COOPERLAKE,
+  zgemm_small_kernel_nn_COOPERLAKE, zgemm_small_kernel_nt_COOPERLAKE, zgemm_small_kernel_nr_COOPERLAKE, zgemm_small_kernel_nc_COOPERLAKE,
+  zgemm_small_kernel_tn_COOPERLAKE, zgemm_small_kernel_tt_COOPERLAKE, zgemm_small_kernel_tr_COOPERLAKE, zgemm_small_kernel_tc_COOPERLAKE,
+  zgemm_small_kernel_rn_COOPERLAKE, zgemm_small_kernel_rt_COOPERLAKE, zgemm_small_kernel_rr_COOPERLAKE, zgemm_small_kernel_rc_COOPERLAKE,
+  zgemm_small_kernel_cn_COOPERLAKE, zgemm_small_kernel_ct_COOPERLAKE, zgemm_small_kernel_cr_COOPERLAKE, zgemm_small_kernel_cc_COOPERLAKE,
+  zgemm_small_kernel_b0_nn_COOPERLAKE, zgemm_small_kernel_b0_nt_COOPERLAKE, zgemm_small_kernel_b0_nr_COOPERLAKE, zgemm_small_kernel_b0_nc_COOPERLAKE,
+  zgemm_small_kernel_b0_tn_COOPERLAKE, zgemm_small_kernel_b0_tt_COOPERLAKE, zgemm_small_kernel_b0_tr_COOPERLAKE, zgemm_small_kernel_b0_tc_COOPERLAKE,
+  zgemm_small_kernel_b0_rn_COOPERLAKE, zgemm_small_kernel_b0_rt_COOPERLAKE, zgemm_small_kernel_b0_rr_COOPERLAKE, zgemm_small_kernel_b0_rc_COOPERLAKE,
+  zgemm_small_kernel_b0_cn_COOPERLAKE, zgemm_small_kernel_b0_ct_COOPERLAKE, zgemm_small_kernel_b0_cr_COOPERLAKE, zgemm_small_kernel_b0_cc_COOPERLAKE,
+#endif
+
   ztrsm_kernel_LN_COOPERLAKE, ztrsm_kernel_LT_COOPERLAKE, ztrsm_kernel_LR_COOPERLAKE, ztrsm_kernel_LC_COOPERLAKE,
   ztrsm_kernel_RN_COOPERLAKE, ztrsm_kernel_RT_COOPERLAKE, ztrsm_kernel_RR_COOPERLAKE, ztrsm_kernel_RC_COOPERLAKE,
 
