@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_CORE2,
+  sbgemm_small_kernel_nn_CORE2, sbgemm_small_kernel_nt_CORE2, sbgemm_small_kernel_tn_CORE2, sbgemm_small_kernel_tt_CORE2,
+  sbgemm_small_kernel_b0_nn_CORE2, sbgemm_small_kernel_b0_nt_CORE2, sbgemm_small_kernel_b0_tn_CORE2, sbgemm_small_kernel_b0_tt_CORE2,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_CORE2, sgemm_otcopy_CORE2,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_CORE2,
+  sgemm_small_kernel_nn_CORE2, sgemm_small_kernel_nt_CORE2, sgemm_small_kernel_tn_CORE2, sgemm_small_kernel_tt_CORE2,
+  sgemm_small_kernel_b0_nn_CORE2, sgemm_small_kernel_b0_nt_CORE2, sgemm_small_kernel_b0_tn_CORE2, sgemm_small_kernel_b0_tt_CORE2,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_CORE2, strsm_kernel_LT_CORE2, strsm_kernel_RN_CORE2, strsm_kernel_RT_CORE2,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_CORE2,
+  dgemm_small_kernel_nn_CORE2, dgemm_small_kernel_nt_CORE2, dgemm_small_kernel_tn_CORE2, dgemm_small_kernel_tt_CORE2,
+  dgemm_small_kernel_b0_nn_CORE2, dgemm_small_kernel_b0_nt_CORE2, dgemm_small_kernel_b0_tn_CORE2, dgemm_small_kernel_b0_tt_CORE2,
+#endif
   dtrsm_kernel_LN_CORE2, dtrsm_kernel_LT_CORE2, dtrsm_kernel_RN_CORE2, dtrsm_kernel_RT_CORE2,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_CORE2, dtrsm_iunncopy_CORE2, dtrsm_iutucopy_CORE2, dtrsm_iutncopy_CORE2,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_CORE2, cgemm_otcopy_CORE2,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_CORE2,
+  cgemm_small_kernel_nn_CORE2, cgemm_small_kernel_nt_CORE2, cgemm_small_kernel_nr_CORE2, cgemm_small_kernel_nc_CORE2,
+  cgemm_small_kernel_tn_CORE2, cgemm_small_kernel_tt_CORE2, cgemm_small_kernel_tr_CORE2, cgemm_small_kernel_tc_CORE2,
+  cgemm_small_kernel_rn_CORE2, cgemm_small_kernel_rt_CORE2, cgemm_small_kernel_rr_CORE2, cgemm_small_kernel_rc_CORE2,
+  cgemm_small_kernel_cn_CORE2, cgemm_small_kernel_ct_CORE2, cgemm_small_kernel_cr_CORE2, cgemm_small_kernel_cc_CORE2,
+  cgemm_small_kernel_b0_nn_CORE2, cgemm_small_kernel_b0_nt_CORE2, cgemm_small_kernel_b0_nr_CORE2, cgemm_small_kernel_b0_nc_CORE2,
+  cgemm_small_kernel_b0_tn_CORE2, cgemm_small_kernel_b0_tt_CORE2, cgemm_small_kernel_b0_tr_CORE2, cgemm_small_kernel_b0_tc_CORE2,
+  cgemm_small_kernel_b0_rn_CORE2, cgemm_small_kernel_b0_rt_CORE2, cgemm_small_kernel_b0_rr_CORE2, cgemm_small_kernel_b0_rc_CORE2,
+  cgemm_small_kernel_b0_cn_CORE2, cgemm_small_kernel_b0_ct_CORE2, cgemm_small_kernel_b0_cr_CORE2, cgemm_small_kernel_b0_cc_CORE2,
+#endif
+
   ctrsm_kernel_LN_CORE2, ctrsm_kernel_LT_CORE2, ctrsm_kernel_LR_CORE2, ctrsm_kernel_LC_CORE2,
   ctrsm_kernel_RN_CORE2, ctrsm_kernel_RT_CORE2, ctrsm_kernel_RR_CORE2, ctrsm_kernel_RC_CORE2,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_CORE2, zgemm_otcopy_CORE2,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_CORE2,
+  zgemm_small_kernel_nn_CORE2, zgemm_small_kernel_nt_CORE2, zgemm_small_kernel_nr_CORE2, zgemm_small_kernel_nc_CORE2,
+  zgemm_small_kernel_tn_CORE2, zgemm_small_kernel_tt_CORE2, zgemm_small_kernel_tr_CORE2, zgemm_small_kernel_tc_CORE2,
+  zgemm_small_kernel_rn_CORE2, zgemm_small_kernel_rt_CORE2, zgemm_small_kernel_rr_CORE2, zgemm_small_kernel_rc_CORE2,
+  zgemm_small_kernel_cn_CORE2, zgemm_small_kernel_ct_CORE2, zgemm_small_kernel_cr_CORE2, zgemm_small_kernel_cc_CORE2,
+  zgemm_small_kernel_b0_nn_CORE2, zgemm_small_kernel_b0_nt_CORE2, zgemm_small_kernel_b0_nr_CORE2, zgemm_small_kernel_b0_nc_CORE2,
+  zgemm_small_kernel_b0_tn_CORE2, zgemm_small_kernel_b0_tt_CORE2, zgemm_small_kernel_b0_tr_CORE2, zgemm_small_kernel_b0_tc_CORE2,
+  zgemm_small_kernel_b0_rn_CORE2, zgemm_small_kernel_b0_rt_CORE2, zgemm_small_kernel_b0_rr_CORE2, zgemm_small_kernel_b0_rc_CORE2,
+  zgemm_small_kernel_b0_cn_CORE2, zgemm_small_kernel_b0_ct_CORE2, zgemm_small_kernel_b0_cr_CORE2, zgemm_small_kernel_b0_cc_CORE2,
+#endif
+
   ztrsm_kernel_LN_CORE2, ztrsm_kernel_LT_CORE2, ztrsm_kernel_LR_CORE2, ztrsm_kernel_LC_CORE2,
   ztrsm_kernel_RN_CORE2, ztrsm_kernel_RT_CORE2, ztrsm_kernel_RR_CORE2, ztrsm_kernel_RC_CORE2,
 
