@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_EXCAVATOR,
+  sbgemm_small_kernel_nn_EXCAVATOR, sbgemm_small_kernel_nt_EXCAVATOR, sbgemm_small_kernel_tn_EXCAVATOR, sbgemm_small_kernel_tt_EXCAVATOR,
+  sbgemm_small_kernel_b0_nn_EXCAVATOR, sbgemm_small_kernel_b0_nt_EXCAVATOR, sbgemm_small_kernel_b0_tn_EXCAVATOR, sbgemm_small_kernel_b0_tt_EXCAVATOR,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_EXCAVATOR, sgemm_otcopy_EXCAVATOR,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_EXCAVATOR,
+  sgemm_small_kernel_nn_EXCAVATOR, sgemm_small_kernel_nt_EXCAVATOR, sgemm_small_kernel_tn_EXCAVATOR, sgemm_small_kernel_tt_EXCAVATOR,
+  sgemm_small_kernel_b0_nn_EXCAVATOR, sgemm_small_kernel_b0_nt_EXCAVATOR, sgemm_small_kernel_b0_tn_EXCAVATOR, sgemm_small_kernel_b0_tt_EXCAVATOR,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_EXCAVATOR, strsm_kernel_LT_EXCAVATOR, strsm_kernel_RN_EXCAVATOR, strsm_kernel_RT_EXCAVATOR,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_EXCAVATOR,
+  dgemm_small_kernel_nn_EXCAVATOR, dgemm_small_kernel_nt_EXCAVATOR, dgemm_small_kernel_tn_EXCAVATOR, dgemm_small_kernel_tt_EXCAVATOR,
+  dgemm_small_kernel_b0_nn_EXCAVATOR, dgemm_small_kernel_b0_nt_EXCAVATOR, dgemm_small_kernel_b0_tn_EXCAVATOR, dgemm_small_kernel_b0_tt_EXCAVATOR,
+#endif
   dtrsm_kernel_LN_EXCAVATOR, dtrsm_kernel_LT_EXCAVATOR, dtrsm_kernel_RN_EXCAVATOR, dtrsm_kernel_RT_EXCAVATOR,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_EXCAVATOR, dtrsm_iunncopy_EXCAVATOR, dtrsm_iutucopy_EXCAVATOR, dtrsm_iutncopy_EXCAVATOR,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_EXCAVATOR, cgemm_otcopy_EXCAVATOR,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_EXCAVATOR,
+  cgemm_small_kernel_nn_EXCAVATOR, cgemm_small_kernel_nt_EXCAVATOR, cgemm_small_kernel_nr_EXCAVATOR, cgemm_small_kernel_nc_EXCAVATOR,
+  cgemm_small_kernel_tn_EXCAVATOR, cgemm_small_kernel_tt_EXCAVATOR, cgemm_small_kernel_tr_EXCAVATOR, cgemm_small_kernel_tc_EXCAVATOR,
+  cgemm_small_kernel_rn_EXCAVATOR, cgemm_small_kernel_rt_EXCAVATOR, cgemm_small_kernel_rr_EXCAVATOR, cgemm_small_kernel_rc_EXCAVATOR,
+  cgemm_small_kernel_cn_EXCAVATOR, cgemm_small_kernel_ct_EXCAVATOR, cgemm_small_kernel_cr_EXCAVATOR, cgemm_small_kernel_cc_EXCAVATOR,
+  cgemm_small_kernel_b0_nn_EXCAVATOR, cgemm_small_kernel_b0_nt_EXCAVATOR, cgemm_small_kernel_b0_nr_EXCAVATOR, cgemm_small_kernel_b0_nc_EXCAVATOR,
+  cgemm_small_kernel_b0_tn_EXCAVATOR, cgemm_small_kernel_b0_tt_EXCAVATOR, cgemm_small_kernel_b0_tr_EXCAVATOR, cgemm_small_kernel_b0_tc_EXCAVATOR,
+  cgemm_small_kernel_b0_rn_EXCAVATOR, cgemm_small_kernel_b0_rt_EXCAVATOR, cgemm_small_kernel_b0_rr_EXCAVATOR, cgemm_small_kernel_b0_rc_EXCAVATOR,
+  cgemm_small_kernel_b0_cn_EXCAVATOR, cgemm_small_kernel_b0_ct_EXCAVATOR, cgemm_small_kernel_b0_cr_EXCAVATOR, cgemm_small_kernel_b0_cc_EXCAVATOR,
+#endif
+
   ctrsm_kernel_LN_EXCAVATOR, ctrsm_kernel_LT_EXCAVATOR, ctrsm_kernel_LR_EXCAVATOR, ctrsm_kernel_LC_EXCAVATOR,
   ctrsm_kernel_RN_EXCAVATOR, ctrsm_kernel_RT_EXCAVATOR, ctrsm_kernel_RR_EXCAVATOR, ctrsm_kernel_RC_EXCAVATOR,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_EXCAVATOR, zgemm_otcopy_EXCAVATOR,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_EXCAVATOR,
+  zgemm_small_kernel_nn_EXCAVATOR, zgemm_small_kernel_nt_EXCAVATOR, zgemm_small_kernel_nr_EXCAVATOR, zgemm_small_kernel_nc_EXCAVATOR,
+  zgemm_small_kernel_tn_EXCAVATOR, zgemm_small_kernel_tt_EXCAVATOR, zgemm_small_kernel_tr_EXCAVATOR, zgemm_small_kernel_tc_EXCAVATOR,
+  zgemm_small_kernel_rn_EXCAVATOR, zgemm_small_kernel_rt_EXCAVATOR, zgemm_small_kernel_rr_EXCAVATOR, zgemm_small_kernel_rc_EXCAVATOR,
+  zgemm_small_kernel_cn_EXCAVATOR, zgemm_small_kernel_ct_EXCAVATOR, zgemm_small_kernel_cr_EXCAVATOR, zgemm_small_kernel_cc_EXCAVATOR,
+  zgemm_small_kernel_b0_nn_EXCAVATOR, zgemm_small_kernel_b0_nt_EXCAVATOR, zgemm_small_kernel_b0_nr_EXCAVATOR, zgemm_small_kernel_b0_nc_EXCAVATOR,
+  zgemm_small_kernel_b0_tn_EXCAVATOR, zgemm_small_kernel_b0_tt_EXCAVATOR, zgemm_small_kernel_b0_tr_EXCAVATOR, zgemm_small_kernel_b0_tc_EXCAVATOR,
+  zgemm_small_kernel_b0_rn_EXCAVATOR, zgemm_small_kernel_b0_rt_EXCAVATOR, zgemm_small_kernel_b0_rr_EXCAVATOR, zgemm_small_kernel_b0_rc_EXCAVATOR,
+  zgemm_small_kernel_b0_cn_EXCAVATOR, zgemm_small_kernel_b0_ct_EXCAVATOR, zgemm_small_kernel_b0_cr_EXCAVATOR, zgemm_small_kernel_b0_cc_EXCAVATOR,
+#endif
+
   ztrsm_kernel_LN_EXCAVATOR, ztrsm_kernel_LT_EXCAVATOR, ztrsm_kernel_LR_EXCAVATOR, ztrsm_kernel_LC_EXCAVATOR,
   ztrsm_kernel_RN_EXCAVATOR, ztrsm_kernel_RT_EXCAVATOR, ztrsm_kernel_RR_EXCAVATOR, ztrsm_kernel_RC_EXCAVATOR,
 
