@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_HASWELL,
+  sbgemm_small_kernel_nn_HASWELL, sbgemm_small_kernel_nt_HASWELL, sbgemm_small_kernel_tn_HASWELL, sbgemm_small_kernel_tt_HASWELL,
+  sbgemm_small_kernel_b0_nn_HASWELL, sbgemm_small_kernel_b0_nt_HASWELL, sbgemm_small_kernel_b0_tn_HASWELL, sbgemm_small_kernel_b0_tt_HASWELL,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_HASWELL, sgemm_otcopy_HASWELL,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_HASWELL,
+  sgemm_small_kernel_nn_HASWELL, sgemm_small_kernel_nt_HASWELL, sgemm_small_kernel_tn_HASWELL, sgemm_small_kernel_tt_HASWELL,
+  sgemm_small_kernel_b0_nn_HASWELL, sgemm_small_kernel_b0_nt_HASWELL, sgemm_small_kernel_b0_tn_HASWELL, sgemm_small_kernel_b0_tt_HASWELL,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_HASWELL, strsm_kernel_LT_HASWELL, strsm_kernel_RN_HASWELL, strsm_kernel_RT_HASWELL,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_HASWELL,
+  dgemm_small_kernel_nn_HASWELL, dgemm_small_kernel_nt_HASWELL, dgemm_small_kernel_tn_HASWELL, dgemm_small_kernel_tt_HASWELL,
+  dgemm_small_kernel_b0_nn_HASWELL, dgemm_small_kernel_b0_nt_HASWELL, dgemm_small_kernel_b0_tn_HASWELL, dgemm_small_kernel_b0_tt_HASWELL,
+#endif
   dtrsm_kernel_LN_HASWELL, dtrsm_kernel_LT_HASWELL, dtrsm_kernel_RN_HASWELL, dtrsm_kernel_RT_HASWELL,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_HASWELL, dtrsm_iunncopy_HASWELL, dtrsm_iutucopy_HASWELL, dtrsm_iutncopy_HASWELL,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_HASWELL, cgemm_otcopy_HASWELL,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_HASWELL,
+  cgemm_small_kernel_nn_HASWELL, cgemm_small_kernel_nt_HASWELL, cgemm_small_kernel_nr_HASWELL, cgemm_small_kernel_nc_HASWELL,
+  cgemm_small_kernel_tn_HASWELL, cgemm_small_kernel_tt_HASWELL, cgemm_small_kernel_tr_HASWELL, cgemm_small_kernel_tc_HASWELL,
+  cgemm_small_kernel_rn_HASWELL, cgemm_small_kernel_rt_HASWELL, cgemm_small_kernel_rr_HASWELL, cgemm_small_kernel_rc_HASWELL,
+  cgemm_small_kernel_cn_HASWELL, cgemm_small_kernel_ct_HASWELL, cgemm_small_kernel_cr_HASWELL, cgemm_small_kernel_cc_HASWELL,
+  cgemm_small_kernel_b0_nn_HASWELL, cgemm_small_kernel_b0_nt_HASWELL, cgemm_small_kernel_b0_nr_HASWELL, cgemm_small_kernel_b0_nc_HASWELL,
+  cgemm_small_kernel_b0_tn_HASWELL, cgemm_small_kernel_b0_tt_HASWELL, cgemm_small_kernel_b0_tr_HASWELL, cgemm_small_kernel_b0_tc_HASWELL,
+  cgemm_small_kernel_b0_rn_HASWELL, cgemm_small_kernel_b0_rt_HASWELL, cgemm_small_kernel_b0_rr_HASWELL, cgemm_small_kernel_b0_rc_HASWELL,
+  cgemm_small_kernel_b0_cn_HASWELL, cgemm_small_kernel_b0_ct_HASWELL, cgemm_small_kernel_b0_cr_HASWELL, cgemm_small_kernel_b0_cc_HASWELL,
+#endif
+
   ctrsm_kernel_LN_HASWELL, ctrsm_kernel_LT_HASWELL, ctrsm_kernel_LR_HASWELL, ctrsm_kernel_LC_HASWELL,
   ctrsm_kernel_RN_HASWELL, ctrsm_kernel_RT_HASWELL, ctrsm_kernel_RR_HASWELL, ctrsm_kernel_RC_HASWELL,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_HASWELL, zgemm_otcopy_HASWELL,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_HASWELL,
+  zgemm_small_kernel_nn_HASWELL, zgemm_small_kernel_nt_HASWELL, zgemm_small_kernel_nr_HASWELL, zgemm_small_kernel_nc_HASWELL,
+  zgemm_small_kernel_tn_HASWELL, zgemm_small_kernel_tt_HASWELL, zgemm_small_kernel_tr_HASWELL, zgemm_small_kernel_tc_HASWELL,
+  zgemm_small_kernel_rn_HASWELL, zgemm_small_kernel_rt_HASWELL, zgemm_small_kernel_rr_HASWELL, zgemm_small_kernel_rc_HASWELL,
+  zgemm_small_kernel_cn_HASWELL, zgemm_small_kernel_ct_HASWELL, zgemm_small_kernel_cr_HASWELL, zgemm_small_kernel_cc_HASWELL,
+  zgemm_small_kernel_b0_nn_HASWELL, zgemm_small_kernel_b0_nt_HASWELL, zgemm_small_kernel_b0_nr_HASWELL, zgemm_small_kernel_b0_nc_HASWELL,
+  zgemm_small_kernel_b0_tn_HASWELL, zgemm_small_kernel_b0_tt_HASWELL, zgemm_small_kernel_b0_tr_HASWELL, zgemm_small_kernel_b0_tc_HASWELL,
+  zgemm_small_kernel_b0_rn_HASWELL, zgemm_small_kernel_b0_rt_HASWELL, zgemm_small_kernel_b0_rr_HASWELL, zgemm_small_kernel_b0_rc_HASWELL,
+  zgemm_small_kernel_b0_cn_HASWELL, zgemm_small_kernel_b0_ct_HASWELL, zgemm_small_kernel_b0_cr_HASWELL, zgemm_small_kernel_b0_cc_HASWELL,
+#endif
+
   ztrsm_kernel_LN_HASWELL, ztrsm_kernel_LT_HASWELL, ztrsm_kernel_LR_HASWELL, ztrsm_kernel_LC_HASWELL,
   ztrsm_kernel_RN_HASWELL, ztrsm_kernel_RT_HASWELL, ztrsm_kernel_RR_HASWELL, ztrsm_kernel_RC_HASWELL,
 
