@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_NEHALEM,
+  sbgemm_small_kernel_nn_NEHALEM, sbgemm_small_kernel_nt_NEHALEM, sbgemm_small_kernel_tn_NEHALEM, sbgemm_small_kernel_tt_NEHALEM,
+  sbgemm_small_kernel_b0_nn_NEHALEM, sbgemm_small_kernel_b0_nt_NEHALEM, sbgemm_small_kernel_b0_tn_NEHALEM, sbgemm_small_kernel_b0_tt_NEHALEM,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_NEHALEM, sgemm_otcopy_NEHALEM,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_NEHALEM,
+  sgemm_small_kernel_nn_NEHALEM, sgemm_small_kernel_nt_NEHALEM, sgemm_small_kernel_tn_NEHALEM, sgemm_small_kernel_tt_NEHALEM,
+  sgemm_small_kernel_b0_nn_NEHALEM, sgemm_small_kernel_b0_nt_NEHALEM, sgemm_small_kernel_b0_tn_NEHALEM, sgemm_small_kernel_b0_tt_NEHALEM,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_NEHALEM, strsm_kernel_LT_NEHALEM, strsm_kernel_RN_NEHALEM, strsm_kernel_RT_NEHALEM,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_NEHALEM,
+  dgemm_small_kernel_nn_NEHALEM, dgemm_small_kernel_nt_NEHALEM, dgemm_small_kernel_tn_NEHALEM, dgemm_small_kernel_tt_NEHALEM,
+  dgemm_small_kernel_b0_nn_NEHALEM, dgemm_small_kernel_b0_nt_NEHALEM, dgemm_small_kernel_b0_tn_NEHALEM, dgemm_small_kernel_b0_tt_NEHALEM,
+#endif
   dtrsm_kernel_LN_NEHALEM, dtrsm_kernel_LT_NEHALEM, dtrsm_kernel_RN_NEHALEM, dtrsm_kernel_RT_NEHALEM,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_NEHALEM, dtrsm_iunncopy_NEHALEM, dtrsm_iutucopy_NEHALEM, dtrsm_iutncopy_NEHALEM,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_NEHALEM, cgemm_otcopy_NEHALEM,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_NEHALEM,
+  cgemm_small_kernel_nn_NEHALEM, cgemm_small_kernel_nt_NEHALEM, cgemm_small_kernel_nr_NEHALEM, cgemm_small_kernel_nc_NEHALEM,
+  cgemm_small_kernel_tn_NEHALEM, cgemm_small_kernel_tt_NEHALEM, cgemm_small_kernel_tr_NEHALEM, cgemm_small_kernel_tc_NEHALEM,
+  cgemm_small_kernel_rn_NEHALEM, cgemm_small_kernel_rt_NEHALEM, cgemm_small_kernel_rr_NEHALEM, cgemm_small_kernel_rc_NEHALEM,
+  cgemm_small_kernel_cn_NEHALEM, cgemm_small_kernel_ct_NEHALEM, cgemm_small_kernel_cr_NEHALEM, cgemm_small_kernel_cc_NEHALEM,
+  cgemm_small_kernel_b0_nn_NEHALEM, cgemm_small_kernel_b0_nt_NEHALEM, cgemm_small_kernel_b0_nr_NEHALEM, cgemm_small_kernel_b0_nc_NEHALEM,
+  cgemm_small_kernel_b0_tn_NEHALEM, cgemm_small_kernel_b0_tt_NEHALEM, cgemm_small_kernel_b0_tr_NEHALEM, cgemm_small_kernel_b0_tc_NEHALEM,
+  cgemm_small_kernel_b0_rn_NEHALEM, cgemm_small_kernel_b0_rt_NEHALEM, cgemm_small_kernel_b0_rr_NEHALEM, cgemm_small_kernel_b0_rc_NEHALEM,
+  cgemm_small_kernel_b0_cn_NEHALEM, cgemm_small_kernel_b0_ct_NEHALEM, cgemm_small_kernel_b0_cr_NEHALEM, cgemm_small_kernel_b0_cc_NEHALEM,
+#endif
+
   ctrsm_kernel_LN_NEHALEM, ctrsm_kernel_LT_NEHALEM, ctrsm_kernel_LR_NEHALEM, ctrsm_kernel_LC_NEHALEM,
   ctrsm_kernel_RN_NEHALEM, ctrsm_kernel_RT_NEHALEM, ctrsm_kernel_RR_NEHALEM, ctrsm_kernel_RC_NEHALEM,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_NEHALEM, zgemm_otcopy_NEHALEM,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_NEHALEM,
+  zgemm_small_kernel_nn_NEHALEM, zgemm_small_kernel_nt_NEHALEM, zgemm_small_kernel_nr_NEHALEM, zgemm_small_kernel_nc_NEHALEM,
+  zgemm_small_kernel_tn_NEHALEM, zgemm_small_kernel_tt_NEHALEM, zgemm_small_kernel_tr_NEHALEM, zgemm_small_kernel_tc_NEHALEM,
+  zgemm_small_kernel_rn_NEHALEM, zgemm_small_kernel_rt_NEHALEM, zgemm_small_kernel_rr_NEHALEM, zgemm_small_kernel_rc_NEHALEM,
+  zgemm_small_kernel_cn_NEHALEM, zgemm_small_kernel_ct_NEHALEM, zgemm_small_kernel_cr_NEHALEM, zgemm_small_kernel_cc_NEHALEM,
+  zgemm_small_kernel_b0_nn_NEHALEM, zgemm_small_kernel_b0_nt_NEHALEM, zgemm_small_kernel_b0_nr_NEHALEM, zgemm_small_kernel_b0_nc_NEHALEM,
+  zgemm_small_kernel_b0_tn_NEHALEM, zgemm_small_kernel_b0_tt_NEHALEM, zgemm_small_kernel_b0_tr_NEHALEM, zgemm_small_kernel_b0_tc_NEHALEM,
+  zgemm_small_kernel_b0_rn_NEHALEM, zgemm_small_kernel_b0_rt_NEHALEM, zgemm_small_kernel_b0_rr_NEHALEM, zgemm_small_kernel_b0_rc_NEHALEM,
+  zgemm_small_kernel_b0_cn_NEHALEM, zgemm_small_kernel_b0_ct_NEHALEM, zgemm_small_kernel_b0_cr_NEHALEM, zgemm_small_kernel_b0_cc_NEHALEM,
+#endif
+
   ztrsm_kernel_LN_NEHALEM, ztrsm_kernel_LT_NEHALEM, ztrsm_kernel_LR_NEHALEM, ztrsm_kernel_LC_NEHALEM,
   ztrsm_kernel_RN_NEHALEM, ztrsm_kernel_RT_NEHALEM, ztrsm_kernel_RR_NEHALEM, ztrsm_kernel_RC_NEHALEM,
 
