@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_ZEN,
+  sbgemm_small_kernel_nn_ZEN, sbgemm_small_kernel_nt_ZEN, sbgemm_small_kernel_tn_ZEN, sbgemm_small_kernel_tt_ZEN,
+  sbgemm_small_kernel_b0_nn_ZEN, sbgemm_small_kernel_b0_nt_ZEN, sbgemm_small_kernel_b0_tn_ZEN, sbgemm_small_kernel_b0_tt_ZEN,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_ZEN, sgemm_otcopy_ZEN,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_ZEN,
+  sgemm_small_kernel_nn_ZEN, sgemm_small_kernel_nt_ZEN, sgemm_small_kernel_tn_ZEN, sgemm_small_kernel_tt_ZEN,
+  sgemm_small_kernel_b0_nn_ZEN, sgemm_small_kernel_b0_nt_ZEN, sgemm_small_kernel_b0_tn_ZEN, sgemm_small_kernel_b0_tt_ZEN,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_ZEN, strsm_kernel_LT_ZEN, strsm_kernel_RN_ZEN, strsm_kernel_RT_ZEN,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_ZEN,
+  dgemm_small_kernel_nn_ZEN, dgemm_small_kernel_nt_ZEN, dgemm_small_kernel_tn_ZEN, dgemm_small_kernel_tt_ZEN,
+  dgemm_small_kernel_b0_nn_ZEN, dgemm_small_kernel_b0_nt_ZEN, dgemm_small_kernel_b0_tn_ZEN, dgemm_small_kernel_b0_tt_ZEN,
+#endif
   dtrsm_kernel_LN_ZEN, dtrsm_kernel_LT_ZEN, dtrsm_kernel_RN_ZEN, dtrsm_kernel_RT_ZEN,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_ZEN, dtrsm_iunncopy_ZEN, dtrsm_iutucopy_ZEN, dtrsm_iutncopy_ZEN,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_ZEN, cgemm_otcopy_ZEN,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_ZEN,
+  cgemm_small_kernel_nn_ZEN, cgemm_small_kernel_nt_ZEN, cgemm_small_kernel_nr_ZEN, cgemm_small_kernel_nc_ZEN,
+  cgemm_small_kernel_tn_ZEN, cgemm_small_kernel_tt_ZEN, cgemm_small_kernel_tr_ZEN, cgemm_small_kernel_tc_ZEN,
+  cgemm_small_kernel_rn_ZEN, cgemm_small_kernel_rt_ZEN, cgemm_small_kernel_rr_ZEN, cgemm_small_kernel_rc_ZEN,
+  cgemm_small_kernel_cn_ZEN, cgemm_small_kernel_ct_ZEN, cgemm_small_kernel_cr_ZEN, cgemm_small_kernel_cc_ZEN,
+  cgemm_small_kernel_b0_nn_ZEN, cgemm_small_kernel_b0_nt_ZEN, cgemm_small_kernel_b0_nr_ZEN, cgemm_small_kernel_b0_nc_ZEN,
+  cgemm_small_kernel_b0_tn_ZEN, cgemm_small_kernel_b0_tt_ZEN, cgemm_small_kernel_b0_tr_ZEN, cgemm_small_kernel_b0_tc_ZEN,
+  cgemm_small_kernel_b0_rn_ZEN, cgemm_small_kernel_b0_rt_ZEN, cgemm_small_kernel_b0_rr_ZEN, cgemm_small_kernel_b0_rc_ZEN,
+  cgemm_small_kernel_b0_cn_ZEN, cgemm_small_kernel_b0_ct_ZEN, cgemm_small_kernel_b0_cr_ZEN, cgemm_small_kernel_b0_cc_ZEN,
+#endif
+
   ctrsm_kernel_LN_ZEN, ctrsm_kernel_LT_ZEN, ctrsm_kernel_LR_ZEN, ctrsm_kernel_LC_ZEN,
   ctrsm_kernel_RN_ZEN, ctrsm_kernel_RT_ZEN, ctrsm_kernel_RR_ZEN, ctrsm_kernel_RC_ZEN,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_ZEN, zgemm_otcopy_ZEN,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_ZEN,
+  zgemm_small_kernel_nn_ZEN, zgemm_small_kernel_nt_ZEN, zgemm_small_kernel_nr_ZEN, zgemm_small_kernel_nc_ZEN,
+  zgemm_small_kernel_tn_ZEN, zgemm_small_kernel_tt_ZEN, zgemm_small_kernel_tr_ZEN, zgemm_small_kernel_tc_ZEN,
+  zgemm_small_kernel_rn_ZEN, zgemm_small_kernel_rt_ZEN, zgemm_small_kernel_rr_ZEN, zgemm_small_kernel_rc_ZEN,
+  zgemm_small_kernel_cn_ZEN, zgemm_small_kernel_ct_ZEN, zgemm_small_kernel_cr_ZEN, zgemm_small_kernel_cc_ZEN,
+  zgemm_small_kernel_b0_nn_ZEN, zgemm_small_kernel_b0_nt_ZEN, zgemm_small_kernel_b0_nr_ZEN, zgemm_small_kernel_b0_nc_ZEN,
+  zgemm_small_kernel_b0_tn_ZEN, zgemm_small_kernel_b0_tt_ZEN, zgemm_small_kernel_b0_tr_ZEN, zgemm_small_kernel_b0_tc_ZEN,
+  zgemm_small_kernel_b0_rn_ZEN, zgemm_small_kernel_b0_rt_ZEN, zgemm_small_kernel_b0_rr_ZEN, zgemm_small_kernel_b0_rc_ZEN,
+  zgemm_small_kernel_b0_cn_ZEN, zgemm_small_kernel_b0_ct_ZEN, zgemm_small_kernel_b0_cr_ZEN, zgemm_small_kernel_b0_cc_ZEN,
+#endif
+
   ztrsm_kernel_LN_ZEN, ztrsm_kernel_LT_ZEN, ztrsm_kernel_LR_ZEN, ztrsm_kernel_LC_ZEN,
   ztrsm_kernel_RN_ZEN, ztrsm_kernel_RT_ZEN, ztrsm_kernel_RR_ZEN, ztrsm_kernel_RC_ZEN,
 
